# Sputtering and Displacement Distributions
# Robert Paruch, Penn State, Chem Dep
# 3/18/2014 

from __future__ import division
import math
import numpy as np
import matplotlib as mpl
import matplotlib.pyplot as plt
import matplotlib.ticker as ticker

averGamma = np.loadtxt('Ag_C60_20keV_0deg-0.9nm-AverGamma_1000_2000.txt')
averDelta = np.loadtxt('Ag_C60_20keV_0deg-0.9nm-AverDelta_1000_2000.txt')

nLayers = 70
averLevelN = int(nLayers/2)
nRange = 20 # -nRange <= j <= nRange - 1; 2 * nRange points

surfRms = 23.5 # rms roughness (A)
dZ = 4 * 2.361 # layer thickness (A)
surfRms /= dZ # A -> ML

mpl.rcParams['axes.labelsize'] = 'large'

ax = plt.subplot(111)
ax.set_xlabel(r'$Layer\ Number\ j$')
ax.set_ylabel(r'$\Gamma_j,\ \Delta_{j \rightarrow j\prime}$')
ax.xaxis.set_major_formatter(ticker.FormatStrFormatter(r'$%.0f$'))
ax.yaxis.set_major_formatter(ticker.FormatStrFormatter(r'$%.0f$'))
ax.grid(True)
ax.vlines(range(-nRange, nRange), 0, averGamma[averLevelN - nRange: averLevelN + nRange], color = 'black', lw = 2, label = r'$\Gamma_j$')
ax.plot(range(-nRange, nRange), np.diag(averDelta, 3)[averLevelN - nRange: averLevelN + nRange], lw = 2, label = r'$\mathrm{\downarrow 3\ layers}$')
ax.plot(range(-nRange, nRange), np.diag(averDelta, 2)[averLevelN - nRange: averLevelN + nRange], lw = 2, label = r'$\mathrm{\downarrow 2\ layers}$')
ax.plot(range(-nRange, nRange), np.diag(averDelta, 1)[averLevelN - nRange: averLevelN + nRange], lw = 2, label = r'$\mathrm{\downarrow 1\ layer}$')
ax.plot(range(-nRange, nRange), np.diag(averDelta, -1)[averLevelN - nRange - 1: averLevelN + nRange - 1], lw = 2, label = r'$\mathrm{\uparrow 1\ layer}$')
ax.plot(range(-nRange, nRange), np.diag(averDelta, -2)[averLevelN - nRange - 2: averLevelN + nRange - 2], lw = 2, label = r'$\mathrm{\uparrow 2\ layers}$')
ax.plot(range(-nRange, nRange), np.diag(averDelta, -3)[averLevelN - nRange - 3: averLevelN + nRange - 3], lw = 2, label = r'$\mathrm{\uparrow 3\ layers}$')
ax.axvline(x = surfRms, c = 'r', ls = '-.', lw = 2, label = r'$\mathrm{\pm 1 \times\ rms}$')
ax.axvline(x = -surfRms, c = 'r', ls = '-.', lw = 2,)
ax.axvline(x = 2 * surfRms, c = 'g', ls = '--', lw = 2, label = r'$\mathrm{\pm 2 \times\ rms}$')
ax.axvline(x = -2 * surfRms, c = 'g', ls = '--', lw = 2,)
ax.set_ylim(0, 250)
handles, labels = ax.get_legend_handles_labels()
ax.legend([handles[8]] + handles[: 8], [labels[8]] + labels[: 8], loc = 'upper left')
ax2 = ax.twinx()
ax2.set_ylabel(r'$Fraction\ that\ remains$')
ax2.xaxis.set_major_formatter(ticker.FormatStrFormatter(r'$%.0f$'))
ax2.yaxis.set_major_formatter(ticker.FormatStrFormatter(r'$%.1f$'))
ax2.plot(range(-nRange, nRange), np.diag(averDelta, 0)[averLevelN - nRange: averLevelN + nRange], '--', lw = 1, label = r'$Remains$')
ax2.set_ylim(0, 1)
ax2.legend(loc = 'center right')
txt = r'$\mathrm{20\ keV,\ 0^\circ\ C_{60}\ sputtering\ of\ Ag(111);\ layer\ thickness\ 1\ nm}$'
ax.text(0.01, 1.08, txt, verticalalignment = 'top', horizontalalignment = 'left', transform = ax.transAxes, color = 'black', backgroundcolor = 'white', fontsize = 14, bbox = dict(boxstyle = 'square', fc = 'w', ec = 'k'))

plt.draw()
# plt.savefig('rpPlotGammaDeltaDistr.png', dpi = 300)
plt.savefig('rpPlotGammaDeltaDistr.pdf')
plt.clf()